"""Blaster metadata."""

__all__ = [
    "__version__"
]

__version__ = "0.5.0"
